summaryrefslogtreecommitdiffstats
path: root/kjsembed/tools/headers/qdir.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/tools/headers/qdir.h')
-rw-r--r--kjsembed/tools/headers/qdir.h144
1 files changed, 72 insertions, 72 deletions
diff --git a/kjsembed/tools/headers/qdir.h b/kjsembed/tools/headers/qdir.h
index 200514dd..4db56e03 100644
--- a/kjsembed/tools/headers/qdir.h
+++ b/kjsembed/tools/headers/qdir.h
@@ -1,7 +1,7 @@
/****************************************************************************
**
**
** Definition of TQDir class
**
** Created : 950427
**
@@ -11,7 +11,7 @@
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** LICENSE.TQPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -27,7 +27,7 @@
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
** information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
+** See http://www.trolltech.com/qpl/ for TQPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
@@ -35,8 +35,8 @@
**
**********************************************************************/
-#ifndef QDIR_H
-#define QDIR_H
+#ifndef TQDIR_H
+#define TQDIR_H
#ifndef QT_H
#include "tqglobal.h"
@@ -46,13 +46,13 @@
#ifndef QT_NO_DIR
-typedef TQPtrList<TQFileInfo> QFileInfoList;
-typedef TQPtrListIterator<TQFileInfo> QFileInfoListIterator;
-class TQStringList;
-template <class T> class TQDeepCopy;
+typedef TTQPtrList<TTQFileInfo> TQFileInfoList;
+typedef TTQPtrListIterator<TTQFileInfo> TQFileInfoListIterator;
+class TTQStringList;
+template <class T> class TTQDeepCopy;
-class Q_EXPORT QDir
+class Q_EXPORT TQDir
{
public:
enum FilterSpec { Dirs = 0x001,
@@ -85,34 +85,34 @@ public:
IgnoreCase = 0x10,
DefaultSort = -1 };
- TQDir();
- TQDir( const TQString &path, const TQString &nameFilter = TQString::null,
+ TTQDir();
+ TTQDir( const TTQString &path, const TTQString &nameFilter = TTQString::null,
int sortSpec = Name | IgnoreCase, int filterSpec = All );
- TQDir( const TQDir & );
+ TTQDir( const TTQDir & );
- virtual ~TQDir();
+ virtual ~TTQDir();
- TQDir &operator=( const TQDir & );
- TQDir &operator=( const TQString &path );
+ TTQDir &operator=( const TTQDir & );
+ TTQDir &operator=( const TTQString &path );
- virtual void setPath( const TQString &path );
- virtual TQString path() const;
- virtual TQString absPath() const;
- virtual TQString canonicalPath() const;
+ virtual void setPath( const TTQString &path );
+ virtual TTQString path() const;
+ virtual TTQString absPath() const;
+ virtual TTQString canonicalPath() const;
- virtual TQString dirName() const;
- virtual TQString filePath( const TQString &fileName,
+ virtual TTQString dirName() const;
+ virtual TTQString filePath( const TTQString &fileName,
bool acceptAbsPath = TRUE ) const;
- virtual TQString absFilePath( const TQString &fileName,
+ virtual TTQString absFilePath( const TTQString &fileName,
bool acceptAbsPath = TRUE ) const;
- static TQString convertSeparators( const TQString &pathName );
+ static TTQString convertSeparators( const TTQString &pathName );
- virtual bool cd( const TQString &dirName, bool acceptAbsPath = TRUE );
+ virtual bool cd( const TTQString &dirName, bool acceptAbsPath = TRUE );
virtual bool cdUp();
- QString nameFilter() const;
- virtual void setNameFilter( const TQString &nameFilter );
+ TQString nameFilter() const;
+ virtual void setNameFilter( const TTQString &nameFilter );
FilterSpec filter() const;
virtual void setFilter( int filterSpec );
SortSpec sorting() const;
@@ -122,30 +122,30 @@ public:
virtual void setMatchAllDirs( bool );
uint count() const;
- QString operator[]( int ) const;
+ TQString operator[]( int ) const;
- virtual TQStrList encodedEntryList( int filterSpec = DefaultFilter,
+ virtual TTQStrList encodedEntryList( int filterSpec = DefaultFilter,
int sortSpec = DefaultSort ) const;
- virtual TQStrList encodedEntryList( const TQString &nameFilter,
+ virtual TTQStrList encodedEntryList( const TTQString &nameFilter,
int filterSpec = DefaultFilter,
int sortSpec = DefaultSort ) const;
- virtual TQStringList entryList( int filterSpec = DefaultFilter,
+ virtual TTQStringList entryList( int filterSpec = DefaultFilter,
int sortSpec = DefaultSort ) const;
- virtual TQStringList entryList( const TQString &nameFilter,
+ virtual TTQStringList entryList( const TTQString &nameFilter,
int filterSpec = DefaultFilter,
int sortSpec = DefaultSort ) const;
- virtual const QFileInfoList *entryInfoList( int filterSpec = DefaultFilter,
+ virtual const TQFileInfoList *entryInfoList( int filterSpec = DefaultFilter,
int sortSpec = DefaultSort ) const;
- virtual const QFileInfoList *entryInfoList( const TQString &nameFilter,
+ virtual const TQFileInfoList *entryInfoList( const TTQString &nameFilter,
int filterSpec = DefaultFilter,
int sortSpec = DefaultSort ) const;
- static const QFileInfoList *drives();
+ static const TQFileInfoList *drives();
- virtual bool mkdir( const TQString &dirName,
+ virtual bool mkdir( const TTQString &dirName,
bool acceptAbsPath = TRUE ) const;
- virtual bool rmdir( const TQString &dirName,
+ virtual bool rmdir( const TTQString &dirName,
bool acceptAbsPath = TRUE ) const;
virtual bool isReadable() const;
@@ -155,92 +155,92 @@ public:
virtual bool isRelative() const;
virtual void convertToAbs();
- virtual bool operator==( const TQDir & ) const;
- virtual bool operator!=( const TQDir & ) const;
+ virtual bool operator==( const TTQDir & ) const;
+ virtual bool operator!=( const TTQDir & ) const;
- virtual bool remove( const TQString &fileName,
+ virtual bool remove( const TTQString &fileName,
bool acceptAbsPath = TRUE );
- virtual bool rename( const TQString &name, const TQString &newName,
+ virtual bool rename( const TTQString &name, const TTQString &newName,
bool acceptAbsPaths = TRUE );
- virtual bool exists( const TQString &name,
+ virtual bool exists( const TTQString &name,
bool acceptAbsPath = TRUE );
static char separator();
- static bool setCurrent( const TQString &path );
- static TQDir current();
- static TQDir home();
- static TQDir root();
- static TQString currentDirPath();
- static TQString homeDirPath();
- static TQString rootDirPath();
-
- static bool match( const TQStringList &filters, const TQString &fileName );
- static bool match( const TQString &filter, const TQString &fileName );
- static TQString cleanDirPath( const TQString &dirPath );
- static bool isRelativePath( const TQString &path );
+ static bool setCurrent( const TTQString &path );
+ static TTQDir current();
+ static TTQDir home();
+ static TTQDir root();
+ static TTQString currentDirPath();
+ static TTQString homeDirPath();
+ static TTQString rootDirPath();
+
+ static bool match( const TTQStringList &filters, const TTQString &fileName );
+ static bool match( const TTQString &filter, const TTQString &fileName );
+ static TTQString cleanDirPath( const TTQString &dirPath );
+ static bool isRelativePath( const TTQString &path );
void refresh() const;
private:
#ifdef Q_OS_MAC
typedef struct FSSpec FSSpec;
- static FSSpec *make_spec(const TQString &);
+ static FSSpec *make_spec(const TTQString &);
#endif
void init();
- virtual bool readDirEntries( const TQString &nameFilter,
+ virtual bool readDirEntries( const TTQString &nameFilter,
int FilterSpec, int SortSpec );
- static void slashify( TQString & );
+ static void slashify( TTQString & );
- QString dPath;
- TQStringList *fList;
- QFileInfoList *fiList;
- QString nameFilt;
+ TQString dPath;
+ TTQStringList *fList;
+ TQFileInfoList *fiList;
+ TQString nameFilt;
FilterSpec filtS;
SortSpec sortS;
uint dirty : 1;
uint allDirs : 1;
void detach();
- friend class TQDeepCopy< TQDir >;
+ friend class TTQDeepCopy< TTQDir >;
};
-inline TQString TQDir::path() const
+inline TTQString TTQDir::path() const
{
return dPath;
}
-inline TQString TQDir::nameFilter() const
+inline TTQString TTQDir::nameFilter() const
{
return nameFilt;
}
-inline TQDir::FilterSpec TQDir::filter() const
+inline TTQDir::FilterSpec TTQDir::filter() const
{
return filtS;
}
-inline TQDir::SortSpec TQDir::sorting() const
+inline TTQDir::SortSpec TTQDir::sorting() const
{
return sortS;
}
-inline bool TQDir::matchAllDirs() const
+inline bool TTQDir::matchAllDirs() const
{
return allDirs;
}
-inline bool TQDir::operator!=( const TQDir &d ) const
+inline bool TTQDir::operator!=( const TTQDir &d ) const
{
return !(*this == d);
}
-struct QDirSortItem {
- TQString filename_cache;
- TQFileInfo* item;
+struct TQDirSortItem {
+ TTQString filename_cache;
+ TTQFileInfo* item;
};
#endif // QT_NO_DIR
-#endif // QDIR_H
+#endif // TQDIR_H
@@ -1,7 +1,7 @@
**
**
-** Definition of TQDir class
+** Definition of TTQDir class
**
** Created : 950427